package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!`````"(```````!``````````)"A````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````%B;````````6)L`````````
M``$```````$````&````6)L```````!8FP$``````%B;`0``````*`4`````
M``!0%0```````````0```````@````8```!HFP```````&B;`0``````:)L!
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````_),```````#\DP```````/R3````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````%B;````````6)L!``````!8FP$`
M`````*@$````````J`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`:+C%:-#B>BTG]:,[U&B1[],*
M^_0$````$`````$```!'3E4```````,````'`````````!$```!+````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""$L```!,````
M3P```%,```!4````7````%T```!>````8````&$```!C````9````&4```!F
M````:0```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5D
MU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,
M9D)%U>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0
MH^#[20`````````````````````````````````````#``L`N!L`````````
M```````````````#`!8``*`!`````````````````$0"```2````````````
M`````````````+L"```2`````````````````````````!0"```2````````
M`````````````````!L"```2`````````````````````````*T"```2````
M`````````````````````+T!```2``````````````````````````$````@
M`````````````````````````&P"```2`````````````````````````(0"
M```2`````````````````````````)X"```B````````````````````````
M`'T"```2`````````````````````````&0"```2````````````````````
M`````'8"```1`````````````````````````$4!```2````````````````
M`````````.T"```2`````````````````````````'0````2````````````
M`````````````-P````2``````````````````````````8"```2````````
M`````````````````&P!```2`````````````````````````-$````1````
M`````````````````````$L"```2`````````````````````````#<!```2
M`````````````````````````+,````1``````````````````````````4!
M```2`````````````````````````,(!```2````````````````````````
M`-$"```2`````````````````````````"("```2````````````````````
M`````',!```2`````````````````````````)L!```2````````````````
M`````````&`!```2`````````````````````````*,!```2````````````
M`````````````/$!```2``````````````````````````T"```2````````
M`````````````````,H!```2`````````````````````````-,!```2````
M`````````````````````+<!```2`````````````````````````!,!```2
M`````````````````````````!T````@`````````````````````````/\"
M```1`````````````````````````.0"```A````````````````````````
M`/D!```2`````````````````````````,,"```2````````````````````
M`````%0````2`````````````````````````#8"```2````````````````
M`````````,H"```2`````````````````````````)(#```2````````````
M`````````````#`"```2`````````````````````````(,````2````````
M`````````````````(\````2`````````````````````````"P!```2````
M`````````````````````%D"```2`````````````````````````/(````2
M`````````````````````````.$````2`````````````````````````$8`
M```2`````````````````````````)0"```2````````````````````````
M`.8````2`````````````````````````%4!```2````````````````````
M`````,`````2`````````````````````````(T"```2````````````````
M`````````&,````2`````````````````````````(\!```2````````````
M`````````````/\!```2`````````````````````````.,"```1````````
M`````````````````.4"```1`````````````````````````)0!```2````
M`````````````````````*0````2`````````````````````````",!```2
M`````````````````````````"D"```2`````````````````````````"P`
M```@`````````````````````````'X!```2````````````````````````
M`.0!```2`````````````````````````.L!```2````````````````````
M`````*\#```0`!<`J+`!`````````````````)L#```2``T`$#\````````P
M`0```````-,#```2``T`8#4````````\!P```````-X"```2``T`P!\`````
M```D`@```````&$#```2``T`\"H````````$`````````'(#```0`!<`@*`!
M`````````````````&\$```2``T`]"H````````@`@```````*4$```2``T`
MH#P```````!L`@```````%L$```0`!<`@*`!`````````````````+H#```2
M``T`%"T````````D`````````.`#```2``T`(%$````````(`0```````/@#
M```1``\`@%0````````$`````````#<$```0`!<`J+`!````````````````
M`#P$```0`!<`J+`!`````````````````&<$```2``T`U"D````````X````
M`````'P$```2``T`-#0````````L`0```````(X$```2``T`A#,```````"0
M`````````.L#```0`!8``*`!`````````````````,<#```2``T`0"T`````
M```8`0```````*<#```0`!8`@*`!`````````````````"T$```1`!8`>*`!
M```````(`````````%$#```2``T`4%0````````$`````````!T$```2``T`
MT%,```````!\`````````/$#```2``T``"(````````\`````````)P$```2
M``T`Q%````````!4`````````.T#```@`!8``*`!`````````````````(`#
M```2``T`%#0````````@`````````*X#```0`!<`J+`!````````````````
M``<$```2``T`$"H```````#@`````````%$$```2``T`,%(```````"4`0``
M`````$0$```2``T`8"X````````D!0````````!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!?7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T`&QS965K-C0`<'1H
M<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M
M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S
M='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A
M9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN
M=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I
M;@!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`
M;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R
M<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E
M;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I
M;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN
M9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI
M=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`````````"``(`
M`@`"``(``@`!``(``@`"``(``@`"``$``@`!``$``@`"``$``@`!``$``0`"
M``(``@`!``,``0`#``(``@`"``(``P`!``$`!``"``(``@`!``(``@`"``(`
M`0`!``$``@`!``(``0`"``$``0`!``(``0`#``(``@`"``,``0`!``(``0`#
M``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``````````$``0`[`P``$````"````"7
MD98&```$`+L$`````````0`!`"$#```0````(````)>1E@8```,`NP0`````
M```!``$`,0,``!``````````EY&6!@```@"[!````````%B;`0```````P0`
M```````0(P```````&";`0```````P0```````#`(@```````(B?`0``````
M`P0```````!05````````-"?`0```````P0```````#04P```````."?`0``
M`````P0```````#`'P````````B@`0```````P0````````(H`$``````!B@
M`0```````P0```````!`6````````""@`0```````P0```````#P5```````
M`#"@`0```````P0```````#@50```````#B@`0```````P0````````@6```
M`````$"@`0```````P0````````H6````````$B@`0```````P0````````P
M6````````%"@`0```````P0````````X6````````&"@`0```````P0`````
M```(6````````&B@`0```````P0````````06````````'B@`0```````P0`
M``````!(6````````)"?`0```````00```D``````````````)B?`0``````
M`00```P``````````````*"?`0```````00```\``````````````*B?`0``
M`````00``!```````````````+"?`0```````00``!8``````````````+B?
M`0```````00``!D``````````````,"?`0```````00``"@`````````````
M`,B?`0```````00``"D``````````````-B?`0```````00``#8`````````
M`````.B?`0```````00``#X``````````````/"?`0```````00``$(`````
M`````````/B?`0```````00``$<``````````````*"=`0```````@0```,`
M`````````````*B=`0```````@0```0``````````````+"=`0```````@0`
M``4``````````````+B=`0```````@0```8``````````````,"=`0``````
M`@0```<``````````````,B=`0```````@0```@``````````````-"=`0``
M`````@0```H``````````````-B=`0```````@0```L``````````````."=
M`0```````@0```P``````````````.B=`0```````@0```T`````````````
M`/"=`0```````@0```X``````````````/B=`0```````@0``!$`````````
M``````">`0```````@0``!(```````````````B>`0```````@0``!,`````
M`````````!">`0```````@0``!0``````````````!B>`0```````@0``!4`
M`````````````"">`0```````@0``!<``````````````"B>`0```````@0`
M`!@``````````````#">`0```````@0``!H``````````````#B>`0``````
M`@0``!L``````````````$">`0```````@0``!P``````````````$B>`0``
M`````@0``!T``````````````%">`0```````@0``!X``````````````%B>
M`0```````@0``!\``````````````&">`0```````@0``"``````````````
M`&B>`0```````@0``"$``````````````'">`0```````@0``"(`````````
M`````'B>`0```````@0``",``````````````(">`0```````@0``"0`````
M`````````(B>`0```````@0``"4``````````````)">`0```````@0``"8`
M`````````````)B>`0```````@0``"<``````````````*">`0```````@0`
M`"@``````````````*B>`0```````@0``"L``````````````+">`0``````
M`@0``"P``````````````+B>`0```````@0``"T``````````````,">`0``
M`````@0``"X``````````````,B>`0```````@0``"\``````````````-">
M`0```````@0``#```````````````-B>`0```````@0``#$`````````````
M`.">`0```````@0``#(``````````````.B>`0```````@0``#,`````````
M`````/">`0```````@0``#0``````````````/B>`0```````@0``#4`````
M``````````"?`0```````@0``#<```````````````B?`0```````@0``#@`
M`````````````!"?`0```````@0``#D``````````````!B?`0```````@0`
M`#H``````````````""?`0```````@0``#L``````````````"B?`0``````
M`@0``#P``````````````#"?`0```````@0``#T``````````````#B?`0``
M`````@0``#\``````````````$"?`0```````@0``$```````````````$B?
M`0```````@0``$,``````````````%"?`0```````@0``$0`````````````
M`%B?`0```````@0``$4``````````````&"?`0```````@0``$8`````````
M`````&B?`0```````@0``$@``````````````'"?`0```````@0``$D`````
M`````````'B?`0```````@0``$H``````````````%\D`]7]>[^I_0,`D9X!
M`)3]>\&HP`-?UO![OZG0``"0$<Y&^1!B-I$@`A_6'R`#U1\@`]4?(`/5T```
MD!'21OD0@C:1(`(?UM```)`1UD;Y$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6
MT```D!'>1OD0XC:1(`(?UM```)`1XD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@
M`A_6T```D!'J1OD00C>1(`(?UM```)`1[D;Y$&(WD2`"'];0``"0$?)&^1""
M-Y$@`A_6T```D!'V1OD0HC>1(`(?UM```)`1^D;Y$,(WD2`"'];0``"0$?Y&
M^1#B-Y$@`A_6T```D!$"1_D0`CB1(`(?UM```)`1!D?Y$"(XD2`"'];0``"0
M$0I'^1!".)$@`A_6T```D!$.1_D08CB1(`(?UM```)`1$D?Y$((XD2`"'];0
M``"0$19'^1"B.)$@`A_6T```D!$:1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"
M'];0``"0$2)'^1`".9$@`A_6T```D!$F1_D0(CF1(`(?UM```)`1*D?Y$$(Y
MD2`"'];0``"0$2Y'^1!B.9$@`A_6T```D!$R1_D0@CF1(`(?UM```)`1-D?Y
M$*(YD2`"'];0``"0$3I'^1#".9$@`A_6T```D!$^1_D0XCF1(`(?UM```)`1
M0D?Y$`(ZD2`"'];0``"0$49'^1`B.I$@`A_6T```D!%*1_D00CJ1(`(?UM``
M`)`13D?Y$&(ZD2`"'];0``"0$5)'^1"".I$@`A_6T```D!%61_D0HCJ1(`(?
MUM```)`16D?Y$,(ZD2`"'];0``"0$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1
M(`(?UM```)`19D?Y$"([D2`"'];0``"0$6I'^1!".Y$@`A_6T```D!%N1_D0
M8CN1(`(?UM```)`1<D?Y$(([D2`"'];0``"0$79'^1"B.Y$@`A_6T```D!%Z
M1_D0PCN1(`(?UM```)`1?D?Y$.([D2`"'];0``"0$8)'^1`"/)$@`A_6T```
MD!&&1_D0(CR1(`(?UM```)`1BD?Y$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6
MT```D!&21_D0@CR1(`(?UM```)`1ED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@
M`A_6T```D!&>1_D0XCR1(`(?UM```)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B
M/9$@`A_6T```D!&J1_D00CV1(`(?UM```)`1KD?Y$&(]D2`"'];0``"0$;)'
M^1""/9$@`A_6T```D!&V1_D0HCV1(`(?UM```)`1ND?Y$,(]D2`"'];0``"0
M$;Y'^1#B/9$@`A_6`````````````````````/U[NJG#``"0_0,`D6/D1_GS
M4P&I]5L"J>*'`ZGBXP"1X0,!D>!/`+G@,P&19`!`^>0O`/D$`(#2BO__E\``
M`)"B``#P`/1'^4+L1_GA`P*J%`T`E*```/``W$?Y``!`.0`*`#33``"0M```
M\)3:1_F``D"Y4___EP)H4CE"`!\R`F@2.8`"0+E.__^7X0,`JN)/0+E`$``1
M5`P`$2)H4CD`?'V30@``,B)H$CE!__^7XP,`JN8C0/G```"08B("D>5/0+D$
M/$#Y`0``\,<`0/DAX!^1````\```()%G!`"I0P0`^60``:F_!`!Q+0D`5"$`
M@-(?(`/5(`P`$<1X8?@A!`"19-@@^+\``6ML__]4I0P`$74B`I%_V"7XX@,4
M*@$``)`$`(#2(8`ED:`.0/F`__^7]`,`*L`$`#1U(@*1]E,!D:`.0/G^_O^7
M````\.$#%JH`P!61@@``E"`$`+1S(@*18`Y`^>;^_Y=E__^7H```\`#D1_GB
M+T#Y`0!`^4(``>L!`(#2P00`5.`#%"KS4T&I]5M"J?U[QJC``U_6_/[_E],`
M`)!B(@*10`P`^4`#`+2T``#PSO[_EX#:1_D``$"Y__[_EQ\D*3FH__\7H`Y`
M^7/__Y?T`P`JV/__%Z`*0/E@``"T6@<`E-W__Q?A`Q:J````\`#@$Y%9``"4
MH`H`^>#Z_[12!P"4U?__%X4`@%+`__\7(`"`4IG^_Y?X_O^7'R`#U1\@`]4?
M(`/5'R`#U1\@`]4?(`/5'R`#U5\D`]4=`(#2'@"`TN4#`*KA`T#YXB,`D>8#
M`)&@``#P`/!'^:,``/!CZ$?YI```\(3$1_F__O^7\O[_EZ```/``X$?Y0```
MM.K^_Q?``U_6P```D````I'!``"0(0`"D3\``.O```!4H0``\"'(1_EA``"T
M\`,!J@`"'];``U_6P```D````I'!``"0(0`"D2$``,LB_'_300R!BR'\09/!
M``"TH@``\$+\1_EB``"T\`,"J@`"'];``U_6'R`#U?U[OJG]`P"1\PL`^=,`
M`)!@`D(Y0`$`-:```/``S$?Y@```M,```)``!$#Y8?[_E]C__Y<@`(!28`("
M.?,+0/G]>\*HP`-?UA\@`]4?(`/5W/__%Q\@`]4?(`/5'R`#U?U[O*G]`P"1
M\U,!J:`&`+3W8P.I]P,`JJ```/``^$?Y&`!`^3@&`+3U6P*I]@,!JA4`@%+@
M`D`Y'_0`<0080'K!`@!4$P-`^=,!`+2U?D"3]`,8JA\@`]7B`Q6JX0,7JN`#
M$ZIG_O^7@```-6!J=3@?]`!Q``(`5)..0/CS_O^U]5M"J?=C0ZG@`Q.J\U-!
MJ?U[Q*C``U_6]0,7JJ`>0#@?]`!Q!!A`>J'__U2U`A=+Y?__%Y0"&,NU!@"1
M<P(5BY3^0Y/4`@"YX`,3JO-30:GU6T*I]V-#J?U[Q*C``U_6$P"`TNG__Q<3
M`(#2]V-#J>;__Q?]>[.IH0``\/T#`)$AY$?Y(@!`^>)G`/D"`(#2P```M/-3
M`:GS`P"J`0!`.6$!`#7S4T&IH```\`#D1_GB9T#Y`0!`^4(``>L!`(#2(0D`
M5/U[S:C``U_6"?[_E_0#`*J`_O^T]V,#J1<``/#X(P&1]R(2D?5;`JG@`Q2J
MD/[_EV`%`+0!3$`Y%4P`D3^X`'%A``!4H09`.0'__S0`3$`Y'[@`<4`%`%3@
M`Q.JV/W_E_8#`*K@`Q6JU?W_E\`"``L`"``1`'Q`DP'^_Y?E`Q6JY`,3JN,#
M%ZKU`P"J`@"`DB$`@%+._?^7X@,8JN$#%:H``(!2TOW_EQ\$`#&@``!4X%M`
MN0`,%!(?$$!QP`(`5.`#%:J:_O^7X`,5JF#^_Y?@`Q2J9O[_E^#Z_[7@`Q2J
M&_[_E^`#$ZI%_O^7\U-!J?5;0JGW8T.IN___%Z`&0#D?N`!QH?K_5*`*0#G@
M^/\TTO__%^`#%:JF__^7Z___%_-3`:GU6P*I]V,#J0S^_Y?]>[6IHP``\.$#
M`*K]`P"18^1'^?,+`/GBHP"1\P,`JF0`0/GD5P#Y!`"`T@``@%(W_O^7(`(`
M->$[0+D"`)12(0P4$C\00'$D$$)ZH`$`5*$``/`AY$?YXU=`^2(`0/EC``+K
M`@"`TH$!`%3S"T#Y_7O+J,`#7]8``(!2]?__%^`#$ZI!`(!2_?W_EQ\``''@
M%Y\:[___%^7]_Y<,"(+2_V,LRZ,``/#B_X'2_7L`J?T#`)%CY$?Y\U,!J?0#
M`*KU6P*I]>,`D?8#`:I@`$#YX!\(^0``@-+A`Q6J````\`!`$I%Z_?^7'P``
M<8T"`%0#!`!1H<IC.*$$`#4#`@`T<WQ`D^`#%:KB`Q.JX06`4B/^_Y=``0"T
MH```\`#81_D``$"YLOW_E^,#$ZKB`Q6JX0,4JB+^_Y<(```4H```\`#81_D`
M`$"YJ?W_E^(#%JKA`Q2JBOW_EZ```/``Y$?YXA](^0$`0/E"``'K`0"`TB$!
M`%0,"(+2_7M`J?-30:GU6T*I_V,LB\`#7];C`P`JW/__%Z;]_Y<?(`/5_7NZ
MJ:(``/#]`P"1\U,!J?,#`*KT`P&J]5L"J?=C`ZE"Y$?Y(`!`.4$`0/GA+P#Y
M`0"`TA_T`'&4%I2:X`,4JBS]_Y?V`P"JX5,!D>`#$ZKH_O^70`@`M/4#`*HE
M_?^7WP(`Z^D&`%3X5X"YMP``\!CS?=-@`D`Y'_0`<0080'I`#`!4Y`,3JH,<
M0#A_]`!Q9!A`>J'__U2$`!/+A'Q`D_?Z1_G`"@"1```$B_8"0/E`_?^7P&HX
M^,`"`+3A`D#YX`,3JB-H>/@!%$`X80``.3_T`'$D&$!ZX```5!\@`]4"%$`X
M8AP`.%_T`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S6@
M``#P`.1'^>(O0/D!`$#Y0@`!ZP$`@-*A!P!4\U-!J?5;0JGW8T.I_7O&J,`#
M7]8!`(#2'R`#U8)J83BB:B$X(00`D:+__S7N__\7MP``\/EK!*G@^D?Y&@!`
M^4`#0/D`!0"TX`,:JA4`@%(?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3
MP0``D"*(0+DB`@`U(@"`4B*(`+D!_?^7^0,`JH`#`+2X?GV3X0,:JN(#&*K#
M_/^7X/I'^1D``/F@!@`1]5<`N3_;(/CY:T2II?__%^$#`*K@`QJJ'?W_E_D#
M`*KA^D?Y(```^4`!`+2X?GV3\___%P0`@-*E__\7``*`TA4`@%+@__\7^6L$
MJ1S]_Y?Y:T2INO__%Q\@`]7]>[ZI_0,`D?,+`/FS``#P<]I'^6`"0+D"_?^7
M8`)`N0#]_Y>B``#P(P``\`$``/!C(`^10M1'^2&`$I$]_?^78`)`N??\_Y?S
M"T#Y!```\/U[PJB$P!^1XP,$J@(``+`!``#P0H`RD2$`$Y$%`(!23/W_%_U[
MOZF@``#P_0,`D0#81_D``$"YYOS_E_U[P:BB``#P(P``\`$``/!"U$?Y8R`/
MD2&`$I$B_?\7'R`#U0P*A-+_8RS+H```\`$(@M+]>P"I_0,`D0#D1_GS4P&I
M\^,`D?43`/GU8R&+%`"`T@$`0/GA)Q#Y`0"`TJ'\_Y?D`P`J!0``\`,``/"E
M8!.18X`3D2(`@M(A`(!2X`,3JG#\_Y?@`Q.JX0,5J@(`@M)X_/^7@`'X-_,#
M`*H`!``1`'Q`DY/\_Y?T`P"JP```M'-^0)/A`Q6JX@,3JE'\_Y>?:C,XH```
M\`#D1_GB)U#Y`0!`^4(``>L!`(#2`0$`5.`#%*H,"H32_7M`J?-30:GU$T#Y
M_V,LB\`#7]:U_/^7R/__%PP<@M+_8RS+H@``\/U[`*G]`P"10N1'^?-3`:GS
M`P&J]5L"J>%3`9'U`P"J0P!`^>-O"/D#`(#2````\`#@$Y'[_?^7]`,`JN$%
M@%+@`Q6J\_S_EV`"`+3A`Q6J````\``@%)'V_O^7X`,5JJ$``/`AY$?YXV](
M^2(`0/EC``+K`@"`TH$,`%0,'(+2_7M`J?-30:GU6T*I_V,LB\`#7];@`Q6J
M]V,#J2'\_Y<7``#P^`,`*N%B%)'@`Q.J&/S_E_,#`*I`"@"T]F,#D?EK!*D:
M``#P&0``\%K#$Y$Y@Q21'R`#U6`"0#E`!@`TM```M.$#$ZK@`Q2JE?S_EZ`$
M`#3@`Q.J"OS_EP($`%%APB*+8\IB.'^\`'$!`0!4X`,"*D($`%$_```Y8<(B
MBV/*8CA_O`!Q0/__5`$'`!$@```+'_P_<0P#`%3D`Q.JY@,5JN4#&:H#``#P
M8Z`4D0(`@M(A`(!2X`,6JO7[_Y?B8P&1X0,6J@``@%+Y^_^7H```->!K0+D`
M#!02'R!`<6`"`%3A8A21``"`TN'[_Y?S`P"J(/K_M?=C0ZGY:T2IJ___%Y0`
M`+2``D`Y'[@`<8```%3S`QJJ(`"`4MS__Q>`!D`Y`/[_-/O__Q?@`Q:J(0"`
M4D_\_Y=@_?\UX0,6J@```/``(!21DO[_E^`#%JHL_/^7]V-#J?EK1*F9__\7
M]V-#J9+__Q?W8P.I^6L$J2S\_Y<"`$`YX0,`JL(``#0A!`"17[P`<0`0@9HB
M`$`Y@O__-<`#7]8?(`/5'R`#U6`(`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.:$&
M`#2Q^_^7`@0`T6("`HM_`@+KHP``5#0``!1"!`#1?P("Z^`!`%1``$`Y'[P`
M<6#__U1_`@+K@@4`5$($`-%_`@+KX```5$``0#D?O`!QX`$`5$($`-%_`@+K
M8?__5&`"0#D?O`!Q8`,`5/,+0/D```#P_7O"J`"`%)'S^_\70`!`.1^\`'&!
M``!40@0`T7\"`NMC__]40@`3RP``@-)!"`"1/P1`\0@!`%3```"0!*`"D4($
M`)'A`Q.JX`,$J@,`@M*U^_^7\PM`^?U[PJC``U_6\PM`^0```/#]>\*H`,`3
MD=G[_Q=_`@+K`?W_5-S__Q<```#P`,`3D=/[_Q<?(`/5'R`#U?U[MZD@``#P
MH@``\``@#Y']`P"1`$``D4+D1_GU6P*IM0``\.&#`9'S4P&I%```\/=C`ZF4
MPA21\W,!D?DC`/FU^D?Y0P!`^>-'`/D#`(#2``1`K0)`0'DB0`!Y(`0`K>$#
M$ZK@`Q2J%OW_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`
M^0`@`)&A__^UX0,3JN`#%*H(_?^78/[_M;4``/`4``#PE`(5D;7Z1_GA`Q.J
MX`,4J@#]_Y?@`0"TH@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`
M(`"1H?__M>$#$ZK@`Q2J\OS_EV#^_[6U``#P%```\)0B%9&U^D?YX0,3JN`#
M%*KJ_/^7X`$`M*("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``
MD:'__[7A`Q.JX`,4JMS\_Y=@_O^UM0``\!0``/"48A61M?I'^>$#$ZK@`Q2J
MU/S_E^`!`+2B`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#%*K&_/^78/[_M;4``-`4``#0EH(5D;7Z1_GA`Q.JX`,6JK[\
M_Y?@`0"TH@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__
MM>$#$ZK@`Q:JL/S_EV#^_[6V``#0%0``T+7"%9'6^D?YX0,3JN`#%:JH_/^7
MX`$`M,("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A
M`Q.JX`,5JIK\_Y=@_O^UM@``T!4``-"WXA.1UOI'^>$#$ZK@`Q>JDOS_E^`!
M`+3"`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3
MJN`#%ZJ$_/^78/[_M;<``-`6``#0V`(6D??Z1_GA`Q.JX`,8JGS\_Y?@`0"T
MX@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@
M`QBJ;OS_EV#^_[6X``#0%P``T/E"%I$8^T?YX0,3JN`#&:IF_/^7X`$`M`(#
M0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,9
MJEC\_Y=@_O^UN0``T!@``-`8@Q:1.?M'^>$#$ZK@`QBJ4/S_E^`!`+0B`T#Y
MXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*I"
M_/^78/[_M;D``-`8``#0&",4D3G[1_GA`Q.JX`,8JCK\_Y?@`0"T(@-`^>-?
M@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ+/S_
MEV#^_[7A`Q.J````T`#`%I$G_/^7X0,`JF```+3@0A:1)_W_E^$#$ZH```#0
M`"`7D1_\_Y?A`P"J@```M````-``@!>1'OW_E^$#$ZH```#0`,`7D1;\_Y?A
M`P"J@`(`M*#B$Y$6_?^7@((5D0$``-`AH!B1$OW_EZ```-``Y$?YXD=`^0$`
M0/E"``'K`0"`TN$#`%3S4T&I]5M"J?=C0ZGY(T#Y_7O)J,`#7];A`Q.J````
MT```&)']^_^7X0,`JH```+3``A:1_?S_E^?__Q<!*HC2XA-'^$'JJ_)AB,GR
MH2CH\E\``>L!_/]4X9-'>,"IAU(_``!K@?O_5,`"%I'A[P&1[OS_E]C__Q>0
M^O^7_7N]J:$``-#]`P"1(>1'^?,+`/FS``#P(@!`^>(7`/D"`(#28!)`N1\$
M`#%@`0!4H0``T"'D1_GC%T#Y(@!`^6,``NL"`(#2(0(`5/,+0/G]>\.HP`-?
MUN&3`)$```#0```6D<[[_Y?A`P"J``"`4J$``+0@`$`Y'\``<0080'K@!Y\:
M8!(`N>K__Q=L^O^7_7N_J?T#`)$9^O^7C/K_ET```+0``$#Y_7O!J,`#7];]
M>[RIH@``T/T#`)%"Y$?Y\U,!J>'3`)'U6P*I%0``T+;"&)%#`$#YXQ\`^0,`
M@-+T`P"JX`,6JJW[_Y>```"T`0!`.?,#`*K!`0`UH```T`#D1_GB'T#Y`0!`
M^4(``>L!`(#2(08`5.$#%*J@PAB1\U-!J?5;0JG]>\2HH/S_%^$#%*JN^O^7
M@`$`M*```-``Y$?YXA]`^0$`0/E"``'K`0"`TB$$`%3S4T&I]5M"J?U[Q*C`
M`U_6X`,4JLSY_Y?U`P"JX`,3JLGY_Y>@`@"+``@`D?;Y_Y?F`Q.J`@"`DB$`
M@%+D`Q2J\P,`J@4``-`#``#0I6`4D6.@%)'`^?^7H@``T$+D1_G@'T#Y00!`
M^0```>L!`(#2@0``5.$#$ZK@`Q:JT___%QGZ_Y<,-I#2_V,LRZ$``-#]>P&I
M_4,`D2'D1_GW8P2IMP``\.)"`)'S4P*I0X``D?5;`ZGV`P"J]/,!D?EK!:GY
MPP*1&```T$:<0*E$%$6I8`1`K6((P#WC(T"1(`!`^6#4`/D``(#2X0,4JD,,
M0/D`XQ.10C!`^2`'`*WF'PBIXTL`^>27":GB5P#YXC>`/4W[_Y>```"T`0!`
M.?,#`*H!(0`U^W,&J9_Y_Y<2^O^70!P`M!H`0/D:'`"TX`,:JH'Y_Y<`^'_3
M``0`D:[Y_Y=$`T`Y]0,`JJ0!`#0;``#0\P,5JGLC&9$?(`/5X`,3JN,#&ZH"
M`("2(0"`4G;Y_Y=S"@"11!]`."3__S4!``#0.2,`D2"`%Y$#```4((=`^,`)
M`+3A`Q2J)_O_E_,#`*I@__^T`0!`.2'__S2_^_^7X/[_-.`#$ZJ_^?^7\P,`
MJD`(`+3@`Q.J6_G_E_H#`*K@`Q6J6/G_EUL#``M[$Q`1&0``T'M_0)/@`QNJ
M@OG_E^<#%:KD`Q.J)8,4D08``-`#``#0QD`9D6-@&9$"`("2^@,`JB$`@%)+
M^?^7X`,:J@$X@%(D^O^7'P0`,:$``%09^O^7!0!`N;]$`'%!%@!4XH,#D>$#
M&JH``(!2VOG_E_,#`"H`!@`TH```T`(``-##`D#YY`,:J@#01_E"H!J1(0"`
M4A4`@-(``$#YLOG_EZ```-#B(T"1`.1'^4/40/D!`$#Y8P`!ZP$`@-)!*`!4
MX`,5J@PVD-+]>T&I\U-"J?5;0ZGW8T2I^6M%J?MS1JG_8RR+P`-?UOH#`I$9
M`(!2'R`#U5/;>?BS`0"T8`)`.6`!`#0Y!P`1X`,3JF_[_Y<@__\TX`,3JF_Y
M_Y?S`P"J(/;_M5/;>?BS_O^U$P"`TJW__Q?@\T"Y``P4$A\00''!^?]4]?M`
MN1OY_Y>_`@!K0?G_5.#S0+D`(``2'P`'<<'X_U3@`QNJ*_G_EP$``-#U`P"J
M(``<D>$#%*JV^O^7P!``M-L"0/E3^?^7X0,`JN`#&ZJE_/^7_`,`JN`/`+3@
M`QRJ[/C_E_L#`*H?#`!Q[0$`5`!\0),!``#0`!``T2$@')&``P"+:_G_EP`!
M`#5_$P!QP!D`5'L7`%&`RWLX'[P`<4`9`%0?(`/5X!)`N1\$`#%@#0!4%```
MT&`.`#2``A:1`0``T"&@&)&6^_^7.8,4D10``-"4PA^1%@``T/GX_Y?6XAR1
MY@,`*N<#%*KE`QFJY`,:JN`#%:H#``#0`@"`DF.@')$A`(!2QOC_EQ$``!28
M^?^7``!`N1]$`'%!`@!4Z/C_E_0#`/ES!@`1Y@,`*N<#$RKE`QFJY`,:JN,#
M%JK@`Q6J`@"`DB$`@%*U^/^7X`,5J@$X@%*.^?^7'P0`,8#]_U3@`QJJ3OG_
ME^$#%:H`XQ.1:_O_E^`#%:JJ_O^7=___%_-C`I$5`(!2'R`#U6#:=?B``0"T
MX0,4JK4&`!%<^O^78/__M`$`0#DA__\T^/C_E_H#`*J`XO^U8-IU^,#^_[6@
M`8#2POC_EQH``-#U`P"J6@,9D60*@%(3__\7H```T.0#&JK#`D#Y`@``T`#0
M1_E"H!F1(0"`4A4`@-(``$#Y!_G_EU7__Q>&_O^7H```T.(C0)$`Y$?Y0]1`
M^0$`0/EC``'K`0"`TL$2`%3@`Q.J##:0TOU[0:GS4T*I]5M#J?=C1*GY:T6I
M_V,LB]#X_Q?<`D#Y@?__%^$#%*H4``#0@`(6D2KZ_Y>@``"T``!`.1_``'$$
M&$!Z`0H`5/\2`+G@`QRJ`0"`4A0``-`H^?^7]@,`*B#Q_S1"`(!2(0*`DO.C
M!I&J^/^7X0,3JN`#%BK"`(#2%OG_E^"C1CF````UX*=&.1\,`7&@"0!4`@"`
M4@$`@-+@`Q8JG?C_EW4%`)3T`P"J!0``%.(#`"KA`Q.JX`,4JH8%`)3A`Q.J
MX`,6*@(`D-("^?^7'P``<>S^_U3@`Q8J\X,%D:GX_Y?\XP61X0,4JAL``-#V
M`Q.J]`,<JI>C`)%[(QF1X`,3JK@%`)0?(`/5Q!9`..`#%*KC`QNJE`H`D0(`
M@)(A`(!2,/C_E_\"%.L!__]4Y@,<JB6#%)'D`QJJ!P``T`,``-#GP!^18V`<
MD0(`@)(A`(!2X`,5JO^#!CDB^/^7X`,:JL#X_Y?A`Q6J`.,3D=WZ_Y?@`Q6J
M'/[_E^G^_Q<@`(!2X!(`N3[__Q?6!D#Y]N;_M.`#%JH/^/^7'PP`\6GF_U0`
M$`#1`0``T,`"`(LA0!R1D/C_EQ\``'&<$Y::*___%^"K1CD?!`%Q0?;_5."O
M1CD?#`%QX?7_5."S1CD?(`%Q@?7_5."W1CD?%`%Q(?7_5.`#%BI"`(!2(0>`
MDD7X_Y?A`Q.JX`,6*B(%@-*Q^/^7Y@,3JB6#%)'D`QJJX`,5J@<``-`#``#0
MY\`?D6-@')$"`("2(0"`4NKW_Y<Z__\73/C_E_MS!JE*^/^7'R`#U?U[NZFA
M``#0_0,`D?-3`:FS``#0]5L"J?83`9%UVD?Y]QL`^2'D1_F@`D"Y(@!`^>(G
M`/D"`(#2*OC_E_0#`*J@`D"Y)_C_E^(#`*J#XD(Y````T.$#%JH`@!610^0"
M.8CY_Y>```"T`0!`.3_$`'&@"P!44_S_EW7:1_F@`D"Y&/C_EP$``-!C`(!2
M(4`=D2(`@%(K^/^7]`,`JH`!`+2@`D"Y#_C_EX$*0/D"``#00F`=D2$`0/GN
M]_^7@`I`^0``0/D`#$"Y0`NP-W?:1_FU``#PX`)`N0+X_Y<!``#08P"`4B&`
M'9$B`(!2%?C_E_0#`*K``0"TX0,6J@```-``(!217_G_E^$"0+GW`P"JX`,!
M*O<'`+3R]_^7@0I`^>(#%ZHA`$#YTO?_EW/:1_FW(@*18`)`N>KW_Y?T`P"J
M8`)`N>?W_Y<B`(!2`0``T"&@'9$?^/^7`@``T.$#`*I"`!Z1X`,4JL+W_Y=@
M`D"YW/?_E^(#`*KA`Q:J````T`#@$Y%?Y`(Y/OG_E^`*`/GS`P"JX`(`M`$X
M@%+@`Q.J6/C_EP$$`!$_!`!Q!(A1>N$$`%2@``#0`.1'^>(G0/D!`$#Y0@`!
MZP$`@-+A`P!4\U-!J?5;0JGW&T#Y_7O%J,`#7]8`!$`Y@/3_-*+__Q?@!D#Y
ML_W_E^`*`/GS`P"JP/S_M0```-``(!Z1]??_E[3W_Y>@(@*1@@I`^0$$0/E`
M`$#Y(0!`^=KY_Y?`__\7H`)`N:OW_Y>!"D#Y(0!`^0#X_Y>B__\7MO?_E[4B
M`I'C`P`JX@,3J@```-``P!Z1H09`^2$`0/G>]_^7'R`#U?U[O*FA``#0_0,`
MD2'D1_GS4P&I]`,`JO5;`JDB`$#YXA\`^0(`@-*"^_^7`0!`.?,#`*K!```T
M``0`D3^\`'%S$H":`0!`.8'__S6V``#PGP(`\?4'GQK`$D"Y'P0`,8`$`%0?
M``!QX`>?&K4"``J5`0`UH```T`#D1_GB'T#Y`0!`^4(``>L!`(#2`04`5/-3
M0:GU6T*I_7O$J,`#7]:``D`Y@/[_-`$``-#@`Q.J(4`9D8(`@-)6]_^7P/W_
M-:```-``Y$?YXA]`^0$`0/E"``'K`0"`TJ$"`%3@`Q2J\U-!J?5;0JG]>\2H
M!OG_%P```+#ATP"1```6D<7X_Y>@``"T``!`.1_``'$$&$!Z80``5-\2`+G7
M__\7(`"`4L`2`+F5^O\TWO__%V'W_Y?_@PK1H0``L.)C`)$%X`"1".`!D>0#
M`JK]>P"I_0,`D2'D1_DC`$#YXT\!^0,`@-*A`$"YA$``D:.$0/@A",!:@0`?
M^&'\8--G_&C3YQQXDB;<>-,A'`A3QAQPDN/@0ZHA``:J(0`#JH&`'_@?`07K
M`?[_5$4`")%!`$#Y0B``D4,$0/E$'$#Y8P`!RD$P0/DA``3*(0`#RB/\7]-A
M!`&J(7Q`DD$\`/E?``7K8?[_5`<H0*DD,X_2""1!J410J_+EFT&I(W2=TN+\
M6]/L_$+30A0'JHQY!ZHA`0C*(]NM\B$`"HHA``G*I0`$BR)`(HM!_4+3(7@*
MJD(`!8L+$$#Y+7Q`DJ4!",K&``2+0@`+"Z4`!XJE``C*(0`,RD[\6]-/_$+3
MI0`)B\X5`JJE``:+(0`"BN)Y`JJE``X+YK]"J2$`#<JN_%O3(0`(B\X5!:JP
M_$+3Q@`$B^\!!(LA``:+A@$"RB$`#@N,?4"2Q@`%BL8`#,HN_%O3Q@`-B\X5
M`:H->@6JQ@`/B\8`#@M%``W*[A]`^4)\0)*E``&*,/Q"TZ4``LK.`02+I0`,
MB\_\6],,>@&J[Q4&JJ$!#,JE``Z+[B-`^:4`#PNM?4"2(0`&BB$`#<K/_$+3
MYGD&JB$``HO"`02+KOQ;TR$``HNO_$+3@@$&RLX5!:HN``X+0@`%BN5Y!:J,
M?4"2X;]$J4(`#,I"``V+S?U;TZT5#JK0?$"2(0`$BT(``8O!``7*30`-"R$`
M#HHA`!#*QOU"T^(!!(O.>`ZJ(0`,BZS]6].F?$"2(0`"BXP5#:JB``[*I?U"
MTR\`#`NE>`VJ0@`-BN&W1:E"``;*0@`0B^S]6].,%0^J\/U"TR$`!(M"``&+
MP0$%RB$`#XK.?4"2(0`.RDP`#`L/>@^JH@$$BR$`!HN&_5O3(0`"BZ(`#\I"
M``R*I7Q`DD(`!<K&%`RJ0@`.BRT`!@OPNT:IAOU"T\9X#*JA_5O3+!0-JN$!
M!LHA``V*[WU`DB$`#\H0`@2+(0`%BT(`$(NP_4+33``,"PUZ#:K"`02+(0`"
MB\(`#<I"``R*QGQ`DD(`!LJ%_5O30@`/BZ44#*KPOT>I+@`%"X7]0M.E>`RJ
MP?U;TRP4#JJA`07*(0`.BJU]0)(0`@2+(0`-RD(`$(O0_4+33``,"PYZ#JKB
M`02+(0`&BR$``HNB``[*0@`,BJ5\0))"``7*AOU;TT(`#8O&%`RJ\+=(J2\`
M!@N&_4+3QG@,JN']6],L%`^JP0$&RB$`#XK.?4"2$`($BR$`#LI"`!"+\/U"
MTTP`#`L/>@^JH@$$BR$`!8LA``*+P@`/RD(`#(K&?$"20@`&RH7]6]-"``Z+
MI10,JO"[2:DM``4+A?U"TZ5X#*JA_5O3+!0-JN$!!<HA``V*[WU`DA`"!(LA
M``_*0@`0B[#]0M-,``P+#7H-JL(!!(LA``:+(0`"BZ(`#<J&_5O3I7Q`DD(`
M#(K&%`RJ0@`%RBX`!@M"``^+AOU"T^&_2JG,>`RJQOU;T\84#JHA``2+Y`$$
MBT(``8NA`0S*(0`.BJU]0)(A``W*S_U"T](``@ON>0ZJ(0`%BT9`)HOO7T#Y
M(0`$BX0!#LI%_EO3A``&2N(!`XNE%!*JA``-BTW^0M.P``$+LGD2JH0``HOB
M8T#Y)4`EB\$!$LH&_EO3)0`%2L84$*I!``.+HD`LBPS^0M//``0+C7D0JD(`
M`8OA9T#YAD`FBT0"#<KE_5O3A``&2J44#ZHF``.+@4`NB[$``@LA``:+[/U"
MTT5`)8OF:T#YCWD/JJ(!#\HD_EO310`%2H04$:K"``.+)OY"TY```0O1>!&J
MYF]`^21`)(OA`1'*K$`RBR0`!$H%_EO3@@$"BZ44$*K!``.+#/Y"TX9`+8NN
M``(+D'D0JL$``8OF<T#Y14`EBR("$,K$_5O30@`%2H04#JK&``.+0D`OB\S]
M0M.-``$+CGD.JD(`!HOF=T#Y)$`DBP$"#LJE_5O3(0`$2J44#:K&``.+(4`Q
MBZ\``@LA``:+K/U"TT5`)8OF>T#YC7D-JL(!#<KD_5O3A!0/JD4`!4K"``.+
MYOU"TY$``0O/>`^JYG]`^21`)(NA`0_*K$`PBR0`!$HE_EO3@@$"BZ44$:K!
M``.++/Y"TX9`+HNP``(+C'D1JL$``8OF@T#Y14`EB^(!#,H$_EO30@`%2H04
M$*K&``.+0D`MBPW^0M..``$+0@`&BZ9Y$*KPAT#Y)$`DBX$!!LK%_5O3(0`$
M2J44#JH0`@.+(4`OBZT``@LA`!"+S_U"TT5`)8OPBT#Y[GD.JL(`#LJD_5O3
MA!0-JD4`!4H"`@.+L/U"TX\``0L->@VJ\(]`^21`)(O!`0W*K$`LBR0`!$KE
M_5O3I10/JH9`)HL!`@.+\/U"T\$``8N"`0*+!GH/JJP``@M%0"6+H@$&RD(`
M!4J$_5O30D`NBX[]0M.$%`RJS'D,JO`[4JF/``$+)$`DB\$`#,KE_5O3(0`$
M2J44#ZHA0"V+[?U"TQ`"`XNO>0^J0@`0B\X!`XNP``(+14`EB^V;0/F"`0_*
M!/Y;TT(`!4HA``Z+A!00JJ4!`XM"0":+#?Y"TXX``0M%``6+HGD0JO"?0/DD
M0"2+X0$"RL;]6],D``1*QA0.J@$"`XN$0"R+T/U"T\T`!0N$``&+`7H.JO"C
M0/FF0":+10`!RJS]6].E``9*C!4-JA`"`XNE0"^+K_U"TXX!!`OO>0VJI0`0
MB_"G0/F,0"R+)``/RL;]6].,``Q*QA0.J@0"`XN"02*+S/U"T\T`!0M"``2+
MA'D.JJ9`)HOE`03*I0`&2J[]0M.P_5O3H4`ABQ`6#:K%>0VJ[#=5J4(`$`M.
M_$+3A@$#BT/\6]-C%`*JC``%JB$`!HN,`0**(0`#"Z,`!`J,`0.JAIN7TF;C
ML?+">0*J@T$OBZP!!HLM_%O38P`,BZT5`:JL``*J[K-`^6,`#0N,`0&*30`%
M"HP!#:HO_$+3X7D!JLX!!HN$022+;?Q;TZT5`ZI,``&JA``.BXP!`XKNMT#Y
MA``-"RT``@IO_$+3C`$-JLX!!HN-_%O3A4$EB^QY`ZJE``Z+HQ4$JBT`#*KN
MNT#YHP`#"Z4!!(J-`0$*C_Q"TZ4`#:K.`0:+I4`BBVW\6]/B>02JK14#JH0!
M`JJE``Z+A``#BNZ_0/FE``T+30`,"F_\0M.$``VJS@$&BX1`(8NM_%O3X7D#
MJJT5!:J$``Z+0P`!JH0`#0LN``(*[<-`^6,`!8JO_$+38P`.JN5Y!:JM`0:+
M8T`LBX[\6]/.%02J+``%JF,`#8N,`02*[<=`^6,`#@NN``$*C`$.JH[\0M."
M02*+K`$&BVW\6]/$>02JK14#JD(`#(M"``T+K``$JNW+0/F.``4*C`$#BF_\
M0M.,`0ZJXWD#JJT!!HN!02&+3OQ;TXP``ZK.%0*J(0`-BR$`#@N,`0**;@`$
M"HP!#JI._$+3PGD"JH5!)8OMNUFI+_Q"TZP!!HLM_%O3K14!JJ4`#(ML``*J
MI0`-"XP!`8I-``,*C`$-JN%Y`:K.`0:+A$$DBZW\6]-,``&JK14%JH0`#HON
MUT#YA``-"XP!!8HM``(*C`$-JJ_\0M/.`0:+@T$CBXW\6]/L>06JK14$JB4`
M#*IC``Z+I0`$BN[;0/EC``T+C0$!"H_\0M.E``VJY'D$JLX!!HNB0"*+;?Q;
MTX4!!*JM%0.J0@`.B^[?0/E"``T+I0`#BHT`#`IO_$+3I0`-JLX!!HNA0"&+
M3?Q;T^5Y`ZJM%0*J@P`%JB$`#HM._$+3(0`-"V,``HK">0*JKP`$"NT[7*EC
M``^J;$`LBR/\6]-C%`&J+_Q"TZT!!HN,`0V+K0`"JH,!`PNL`0&*30`%"N%Y
M`:J,`0VJ;?Q;TX1!)(O,`0:+A``,BTP``:HN``(*C`$#BHP!#JJM%0.JA4$E
MBX0`#0OO,UVI;?Q"TZUY`ZJ._%O3SA4$JN\!!HNC``^+)0`-JF,`#@NE``2*
MK@$!"J4`#JJ._$+3Q'D$JJ)`(HN%`0:+;/Q;TXP5`ZI"``6+;OQ"TZ4!!*I"
M``P+I0`#BL-Y`ZJ/``T*[#M>J:4`#ZJE0"&+0?Q;TR$4`JI/_$+3C`$&BZ4`
M#(N,``.JI0`!"XP!`HIA``0*XGD"JHP!`:I0``,*@4$MB\T!!HNL_%O3(0`-
MBXP5!:IM``*J[_M`^8X!`0NM`06*+$`LBZT!$*K0_4+3I$$DB^T!!HNO_$+3
MQOU;TX0`#8O&%`ZJ[7D%JM(`!`OO_T#Y00`-RB$`#$K%.IC214RY\B%`(XOL
M`06+0_Y;TPYZ#JHA``R+8Q02JH9`)HOL`T'Y<0`!"Z0!#LHC0".+A``&2H8!
M!8N"0"*+3/Y"TR3^6].2>1*J0@`&BX04$:KF!T'YD``""\$!$LI$0"2+(P`#
M2L$`!8ML0"V+)OY"TP/^6]/1>!&JC`$!BV,4$*KA"T'Y;P`,"T("$<J#02.+
M1``$2B(`!8N&0"Z+X?U;TP3^0M/&``*+D'@0JB$4#ZKB#T'Y+@`&"R0"$,KL
M_4+3A``#2D,`!8N$0#*+POU;TX]Y#ZJ$``.+0A0.JL%`(8OC$T'Y30`$"P8"
M#\K,_4+3P0`!2F8`!8LC0#&+H?U;TXYY#JIC``:+(10-JH)`(HOF%T'Y,@`#
M"^0!#LIA0"&+@@`"2L0`!8M,0#"+IOU"TT+^6]/->`VJA`$$BT(4$JKF&T'Y
M40`$"\,!#<I,_D+380`!2L,`!8LF0"^+(?Y;T\,``XN,>1*J(101JH)`(HOF
M'T'Y,``#"Z0!#,IA0"&+@@`"2L8`!8M$0"Z++OY"TP+^6].$``:+0A00JL9Y
M$:KN(T'Y3P`$"X,!!LJ"0"*+80`!2LX!!8LC0"V+#?Y"T^']6].P>1"J8P`.
MBR$4#ZKN)T'Y+0`#"\0`$,IA0"&+@@`"2L0!!8M,0"R+[OU"TZ+]6]//>0^J
MA`$$BT(4#:KL*T'Y3@`$"P,"#\J"0"*+80`!2H,!!8LF0":+K/U"T\']6]/#
M``.+(10.JH9Y#:KL+T'Y+0`#"^0!!LIA0"&+@@`"2HP!!8M$0#"+T/U"TZ+]
M6],.>@ZJA``,BT(4#:KL,T'Y40`$"\,`#LJ"0"*+80`!2HP!!8LC0"^+K_U"
MTR'^6]/M>0VJ8P`,BR$4$:KL-T'Y,``#"\0!#<HO_D+3@@`"2H0!!8M,0":+
M`OY;TX8!!(M"%!"J['D1JF%`(8OD.T'Y3P`&"Z,!#,K"0"*+80`!2H,`!8LD
M0"Z+#OY"T^']6].$``.+(10/JL-Y$*KP/T'Y+@`$"X8!`\J!0"&+P@`"2A`"
M!8M&0"V+[?U"T\+]6].O>0^J0A0.JL8`$(OM0T'Y4``&"V0`#\K&0"*+A``!
M2J$!!8N,0"R+S?U"TP3^6].,`0&+A!00JJYY#JKA1T'Y@@`,"^T!#LKG0"^+
MK0$&2B8`!8NC02.+0?Q;TR$4`JIC``:+8P`!"P'^0M/M2T'Y(7@0JH9!)(O0
M`0'*9/Q;TZP``)`/`@9*A!0#JJ8!!8M%_$+3Q@`'BZ)X`JJ'Y4?YA``/BR$`
M"0O%`0L+8P`*"X0`!@M"``@+!`P`J0($`:D%$`#YX$]!^>$`0/D```'K`0"`
MTH$``%3]>T"I_X,*D<`#7]9`\_^7_7N_J0`0@-+]`P"1!//_EQ\8`/DF8(32
M)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E^;WR1!>S\D,&HO)">KCR!A0`J00,`:D"
M?`*I'W@`N?U[P:C``U_6'R`#U1\@`]7]>[RI0GQ`D_T#`)'S4P&I%.``D?,#
M`:KU6P*I]0,`JO8#`JKW8P.I!8Q"J0!X0+FD#`(+OP`$ZV.4@YIB=$*+I(H"
MJ:`#`#7?_@!QK04`5-8"`5'8?@93%P<`$?=J>M-W`A>+'R`#U6`&0*W@`Q6J
M@`8`K6`&0:US`@&1@`8!K:C[_Y=_`A?K`?__5-8:&$OA`Q>JX`,4JL)^0).-
M\O^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6%PB`4O<"`$O_`A9K@,(@B_?2
MEAKX?D"3X@,8JG_R_Y>@>D"YX`(`"Z!Z`+D?``%QX?W_5-8"%TMS`AB+X`,5
MJHK[_Y?3__\7]P,3JN/__Q<?(`/5'R`#U?U[O*GB#X`2_0,`D?-3`:GT`P"J
M\P,!JO5;`JDUX`"1]QL`^2`40/DV*$"Y-S!`N0`@`U/6"L!:`00`$?<*P%JB
MRB`XH,(ABS_@`'&-"0!4`@B`4D(``4L!`(!20GQ`DZSR_Y?@`Q.J:OO_EW\V
M`/D`!`!/H`(`K:`*@#W@`Q.J=UH.*6/[_Y=A`D#YX`,3JB'\6-.!`@`Y80)`
M^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.`#EA!D#Y(?Q8TX$2`#EA!D#Y
M(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`.6$*0/DA_%C3@2(`.6$*0/DA
M_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y80Y`^2'\6-.!,@`Y80Y`^2'\
M4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA$D#Y(?Q8TX%"`#EA$D#Y(?Q0
MTX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.?-30:GU6T*I]QM`^?U[Q*C"\O\7
M`@>`4D(``4L!`(!20GQ`DV'R_Y>[__\7'R`#U1\@`]4?(`/5_7N\J?T#`)'S
M4P&IM```D)2"+9'U6P*IM0``D+5B+9&4`A7+]@,`*O=C`ZGW`P&J^`,"JI3^
M0Y/L\?^7=`$`M!,`@-(?(`/5HWIS^.(#&*IS!@"1X0,7JN`#%BI@`#_6GP(3
MZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UA\@`]7``U_6'R`#U1\@`]4?(`/5
MHP``L&,$0/D.\O\77R0#U?U[OZG]`P"1_7O!J,`#7]8!``(``````"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E
M:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.04U%
M`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!0
M15),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P``
M``````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````
M4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]
M````````,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X````
M`'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%4
M2`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP
M+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`
M````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,@```%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```````````M90```````"TM````````55-%4@````!5
M4T523D%-10``````````5$U01$E2``!414U01$E2`%1%35``````5$U0````
M```O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA
M;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@
M,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N
M=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M
M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O
M9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?
M<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`]
M(#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@
M,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC
M7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P
M;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M
M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?
M<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B
M.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N
M86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L
M("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@
M979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]
M('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V
M95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@
M)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U
M;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N
M(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W
M<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,`````
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```````1L#.P@!
M```@````Q(O__QP&```$CO__(`$``%2.__\T`0``A([__T@!``#$CO__7`$`
M`!2/__^``0``)(___Y0!```8D/___`$``)B1__]<`@``-)+__X0"```TD___
MO`(``&25__\0`P``V)7__S0#```4EO__5`,``/26__^(`P``^);__YP#```8
MF?__"`0``$29__\<!```9)K__U@$``"(G___E`0``!B@__^X!```.*#__]@$
M``!DH?__%`4``*2H__^L!0``%*O__^`%``!$K/__3`8``,B\__]P!@``)+W_
M_Y`&```TOO__R`8``-2____\!@``5,#__S`'``!DP/__1`<``!``````````
M`7I2``1X'@$;#!\`$````!@```#<C/__/`````!!!QX0````+````!B-__\P
M`````````!````!`````-(W__SP`````````(````%0```!@C?__2`````!!
M#B"=!)X#0I,"3M[=TPX`````$````'@```",C?__!`````````!D````C```
M`(B-___T`````$$.0)T(G@="DP:4!4*8`9<"1I8#E016UM5!V-=#WMW3U`X`
M00Y`DP:4!94$E@.7`I@!G0B>!T_6U4'8UT'>W=/4#@!!#D"3!I0%G0B>!T*7
M`I@!0MC7`%P```#T````%([__X`!````00[0`9T:GAE(E!>3&$34TTC>W0X`
M00[0`9,8E!>=&IX91)@3EQ1$EA65%G(*U--!UM5!V-=!"TG3U-76U]A!E!>3
M&$&6%94609@3EQ0``"0```!4`0``-(___YP`````00ZP`9T6GA5%DQ17"M[=
MTPX`00L````T````?`$``*B/___\`````$(.P"!#G8@$GH<$0Y.&!)2%!$*5
MA`26@P1Q"MW>U=;3U`X`00L``%````"T`0``<)#__RP"````00Y@G0R>"T.3
M"I0)3)4(E@>7!I@%?PK>W=?8U=;3U`X`00M)F@.9!%\*VME!"TG9VD*9!)H#
M0]G:09H#F01"VMD``"`````(`@``3)+__W0`````00X@G02>`T*3`E+>W=,.
M`````!P````L`@``G)+__S@`````00X0G0*>`4;>W0X`````,````$P"``"X
MDO__X`````!"#M!`0YV*")Z)"$.3B`B4APA"E88(;`K=WM73U`X`00L``!``
M``"``@``9)/__P0`````````:````)0"``!4D___(`(```!"#N`A0IV<!)Z;
M!$.3F@24F01#E9@$EI<$70K=WM76T]0.`$$+0IB5!)>6!$J:DP29E`1V"MC7
M0=K900M5V-=!VME!EY8$F)4$0=C70IB5!)>6!$&:DP29E`0`$``````#```(
ME?__)``````````X````%`,``""5__\8`0```$(.()T$G@-"DP)@"M[=TPX`
M0@M4"M[=TPX`00M#"M[=TPX`0@M##@#3W=XX````4`,```26__\D!0```$$.
MD`&=$IX11Y4.E@U#DQ"4#T67#)@+F0H#'P$*WMW9U]C5UM/4#@!!"P`@````
MC`,``.R:__^0`````$$.,)T&G@5$DP10"M[=TPX`00L<````L`,``%B;__\@
M`````$$.$)T"G@%&WMT.`````#@```#0`P``6)O__RP!````00Y`G0B>!T:3
M!I0%E026`U@*WMW5UM/4#@!!"TT*WMW5UM/4#@!!"P```)0````,!```2)S_
M_SP'````0@ZP@P)"G;0@GK,@0Y>N()BM($63LB"4L2"5L""6KR!#F:P@FJL@
M6IRI()NJ(`)J"MS;0=W>V=K7V-76T]0.`$$+`IK;W%'=WMG:U]C5UM/4#@!!
M#K"#`I.R()2Q()6P():O()>N()BM()FL()JK()NJ()RI()VT()ZS(`*,V]Q!
MG*D@FZH@,````*0$``#PHO__;`(```!!#E"="IX)0Y,(E`="E0:6!4.7!`)O
M"M[=U]76T]0.`$$+`#@```#8!```+*7__S`!````00Y`G0B>!T23!I0%0I4$
ME@-@"M[=U=;3U`X`00M3"M[=U=;3U`X`00L``"P````4!0``H(7__R0"````
M00Y@G0R>"T63"I0)E0B6!P)A"M[=U=;3U`X`00L``"````!$!0``\*7__X00
M````00Z@!4:=5)Y3`Q@$"MW>#@!!"QP```!H!0``4+;__U0`````00X0G0*>
M`5/>W0X`````-````(@%``",MO__"`$```!!#D"=")X'0Y,&E`5#E026`T.7
M`I@!8PK>W=?8U=;3U`X`00L````P````P`4``&2W__^4`0```$$.0)T(G@=#
MDP:4!4.5!)8#0I<"`E4*WMW7U=;3U`X`00L`,````/0%``#0N/__?`````!!
M#D"=")X'0I,&E`5#E026`T67`I@!4][=U]C5UM/4#@```!`````H!@``'+G_
M_P0`````````$````#P&```8N?__#```````````````$",```````#`(@``
M``````$`````````$0,````````!`````````"$#`````````0`````````Q
M`P````````$`````````.P,````````,`````````+@;````````#0``````
M``!L5````````!D`````````6)L!```````;``````````@`````````&@``
M``````!@FP$``````!P`````````"`````````#U_O]O`````)@"````````
M!0````````!X#0````````8`````````B`,````````*`````````,8$````
M````"P`````````8`````````!4````````````````````#`````````(B=
M`0```````@````````"@!0```````!0`````````!P`````````7````````
M`!@6````````!P````````!X$P````````@`````````H`(````````)````
M`````!@`````````'@`````````(`````````/O__V\``````0``"`````#^
M__]O`````!@3````````____;P`````#`````````/#__V\`````/A(`````
M``#Y__]O`````!``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#0&P```````-`;````
M````T!L```````#0&P```````-`;````````T!L```````#0&P```````-`;
M````````T!L```````#0&P```````-`;````````T!L```````#0&P``````
M`-`;````````T!L```````#0&P```````-`;````````T!L```````#0&P``
M`````-`;````````T!L```````#0&P```````-`;````````T!L```````#0
M&P```````-`;````````T!L```````#0&P```````-`;````````T!L`````
M``#0&P```````-`;````````T!L```````#0&P```````-`;````````T!L`
M``````#0&P```````-`;````````T!L```````#0&P```````-`;````````
MT!L```````#0&P```````-`;````````T!L```````#0&P```````-`;````
M````T!L```````#0&P```````-`;````````T!L```````#0&P```````-`;
M````````T!L```````#0&P```````-`;````````T!L```````#0&P``````
M`-`;````````T!L```````!HFP$``````%!4````````````````````````
M````````````````````````````````````````````````````````````
M`````````-!3``````````````````#`'P``````````````````````````
M````````````````````````"*`!``````#_____`````$!8````````\%0`
M`````````````````.!5````````(%@````````H6````````#!8````````
M.%@```````````````````A8````````$%@``````````````````$A8````
M````1T-#.B`H1&5B:6%N(#$Q+C(N,"TQ,"D@,3$N,BXP```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"````
M````.`(````````;`````````````````````0```````````````````!,`
M```'`````@````````!4`@```````%0"````````)```````````````````
M``0````````````````````F````!P````(`````````>`(```````!X`@``
M`````"`````````````````````$````````````````````-````/;__V\"
M`````````)@"````````F`(```````#P``````````4`````````"```````
M`````````````#X````+`````@````````"(`P```````(@#````````\`D`
M```````&`````P````@`````````&`````````!&`````P````(`````````
M>`T```````!X#0```````,8$```````````````````!````````````````
M````3@```/___V\"`````````#X2````````/A(```````#4``````````4`
M`````````@`````````"`````````%L```#^__]O`@`````````8$P``````
M`!@3````````8``````````&`````P````@```````````````````!J````
M!`````(`````````>!,```````!X$P```````*`"````````!0`````````(
M`````````!@`````````=`````0```!"`````````!@6````````&!8`````
M``"@!0````````4````5````"``````````8`````````'X````!````!@``
M``````"X&P```````+@;````````&`````````````````````0`````````
M``````````!Y`````0````8`````````T!L```````#0&P```````.`#````
M```````````````0````````````````````A`````$````&`````````,`?
M````````P!\```````"L-```````````````````0```````````````````
M`(H````!````!@````````!L5````````&Q4````````%```````````````
M``````0```````````````````"0`````0````(`````````@%0```````"`
M5````````'H_```````````````````(````````````````````F`````$`
M```"`````````/R3````````_),````````,`0``````````````````!```
M`````````````````*8````!`````@`````````(E0````````B5````````
M4`8```````````````````@```````````````````"P````#@````,`````
M````6)L!``````!8FP````````@````````````````````(``````````@`
M````````O`````\````#`````````&";`0``````8)L````````(````````
M````````````"``````````(`````````,@````&`````P````````!HFP$`
M`````&B;````````(`(````````&``````````@`````````$`````````#1
M`````0````,`````````B)T!``````"(G0```````'@"````````````````
M```(``````````@`````````U@````$````#``````````"@`0```````*``
M``````"`````````````````````"````````````````````-P````(````
M`P````````"`H`$``````("@````````*!````````````````````@`````
M``````````````#A`````0```#````````````````````"`H````````!\`
M```````````````````!``````````$``````````0````,`````````````
M````````````GZ````````#J`````````````````````0``````````````
$````````
